@@ -2,7 +2,7 @@
 #
 #       findreplace.py
 #
-#       Copyright 2009-2015 Giuseppe Penone <giuspen@gmail.com>
+#       Copyright 2009-2016 Giuseppe Penone <giuspen@gmail.com>
 #
 #       This program is free software; you can redistribute it and/or modify
 #       it under the terms of the GNU General Public License as published by
@@ -21,7 +21,7 @@
 
 import gtk, gobject
 import re, cgi, time
-import cons, support, config
+import cons, menus, support, config
 
 
 class FindReplace:
@@ -38,6 +38,7 @@ class FindReplace:
         self.newline_trick = False
         self.allmatchesdialog_init()
         self.iteratedfinddialog = None
+        self.latest_node_offset = {}
 
     def iterated_find_dialog_exist_or_create(self):
         """Exist or Create the Iterated Find Dialog"""
@@ -94,11 +95,12 @@ class FindReplace:
         elif response == 4:
             # find backward
             self.find_back()
-    
+
     def find_in_selected_node(self):
         """Search for a pattern in the selected Node"""
         entry_hint = ""
         if not self.from_find_iterated:
+            self.latest_node_offset = {}
             iter_insert = self.dad.curr_buffer.get_iter_at_mark(self.dad.curr_buffer.get_insert())
             iter_bound = self.dad.curr_buffer.get_iter_at_mark(self.dad.curr_buffer.get_selection_bound())
             entry_predefined_text = self.dad.curr_buffer.get_text(iter_insert, iter_bound)
@@ -151,6 +153,7 @@ class FindReplace:
     def find_in_all_nodes(self, father_tree_iter):
         """Search for a pattern in all the Tree Nodes"""
         if not self.from_find_iterated:
+            self.latest_node_offset = {}
             iter_insert = self.dad.curr_buffer.get_iter_at_mark(self.dad.curr_buffer.get_insert())
             iter_bound = self.dad.curr_buffer.get_iter_at_mark(self.dad.curr_buffer.get_selection_bound())
             entry_predefined_text = self.dad.curr_buffer.get_text(iter_insert, iter_bound)
@@ -219,7 +222,7 @@ class FindReplace:
                 node_iter = self.dad.treestore.iter_parent(last_top_node_iter)
                 if node_iter:
                     last_top_node_iter = node_iter.copy()
-                    # we do not check the father on purpose, only the uncles in the proper direction
+                    # we do not check the parent on purpose, only the uncles in the proper direction
                     if forward: node_iter = self.dad.treestore.iter_next(node_iter)
                     else: node_iter = self.dad.get_tree_iter_prev_sibling(self.dad.treestore, node_iter)
                 else: break
@@ -307,7 +310,7 @@ class FindReplace:
                 node_iter = self.dad.treestore.iter_parent(last_top_node_iter)
                 if node_iter != None:
                     last_top_node_iter = node_iter.copy()
-                    # we do not check the father on purpose, only the uncles in the proper direction
+                    # we do not check the parent on purpose, only the uncles in the proper direction
                     if forward: node_iter = self.dad.treestore.iter_next(node_iter)
                     else: node_iter = self.dad.get_tree_iter_prev_sibling(self.dad.treestore, node_iter)
                 else: break
@@ -389,7 +392,7 @@ class FindReplace:
             self.dad.state_machine.update_state()
             self.dad.ctdb_handler.pending_edit_db_node_buff(self.dad.treestore[tree_iter][3], force_user_active=True)
         return True
-    
+
     def check_pattern_in_object(self, pattern, obj):
         """Search for the pattern in the given object"""
         if obj[0] == "pixbuf":
@@ -445,7 +448,7 @@ class FindReplace:
             curr_offset = next_offset
         return num_objs
 
-    def get_inner_start_iter(self, text_buffer, forward):
+    def get_inner_start_iter(self, text_buffer, forward, node_id):
         """Get start_iter when not at beginning or end"""
         if text_buffer.get_has_selection():
             iter_start, iter_end = text_buffer.get_selection_bounds()
@@ -465,7 +468,14 @@ class FindReplace:
                 start_iter = text_buffer.get_iter_at_offset(min(offsets))
             else:
                 start_iter = text_buffer.get_iter_at_offset(max(offsets))
-        print offsets, start_iter.get_offset()
+        if self.latest_node_offset\
+        and self.latest_node_offset["n"] == node_id\
+        and self.latest_node_offset["o"] == start_iter.get_offset():
+            if forward: start_iter.forward_char()
+            else: start_iter.backward_char()
+        self.latest_node_offset["n"] = node_id
+        self.latest_node_offset["o"] = start_iter.get_offset()
+        #print self.latest_node_offset["n"], offsets, self.latest_node_offset["o"]
         return start_iter
 
     def parse_node_content_iter(self, tree_iter, text_buffer, pattern, forward, first_fromsel, all_matches, first_node):
@@ -481,7 +491,8 @@ class FindReplace:
             restore_modified = False
         if (first_fromsel and first_node)\
         or (all_matches and not self.all_matches_first_in_node):
-            start_iter = self.get_inner_start_iter(text_buffer, forward)
+            node_id = self.dad.get_node_id_from_tree_iter(tree_iter)
+            start_iter = self.get_inner_start_iter(text_buffer, forward, node_id)
         else:
             if forward: start_iter = text_buffer.get_start_iter()
             else: start_iter = text_buffer.get_end_iter()
@@ -626,7 +637,7 @@ class FindReplace:
         """Create the All Matches Dialog"""
         self.allmatchesdialog = gtk.Dialog(parent=self.dad.window,
             flags=gtk.DIALOG_MODAL|gtk.DIALOG_DESTROY_WITH_PARENT,
-            buttons=(_("Hide (Restore with Ctrl+Shift+A)"), gtk.RESPONSE_CLOSE))
+            buttons=(_("Hide (Restore with '%s')") % menus.get_menu_item_kb_shortcut(self.dad, "toggle_show_allmatches_dlg"), gtk.RESPONSE_CLOSE))
         self.allmatchesdialog.set_default_size(700, 350)
         self.allmatchesdialog.set_position(gtk.WIN_POS_CENTER_ON_PARENT)
         try:
